load('JolloisPoggiPortier.Rdata')
library(flexmix)

clus_reg = function(x, st = 'XXX') {
# Clusterwise regression with flexmix package
# Input :
#	x : data matrix
#	st : station name
	# shell is for Windows. 
	# Under Unix-like system, use system() function
	if (all(dir() != "CR")) shell('mkdir CR')
	setwd('CR')
	if (all(dir() != st)) shell(paste('mkdir', st))
	setwd(st)
	# Scaling data 
	x =  as.data.frame(scale(x))
	# Run flexmix for k=1:7
	res =  stepFlexmix(formula(x), data=x, k=1:7,
		nrep=10, control=list(iter.max=500))
	sink(paste('CR_', st, '_ClusReg.txt', sep=''))
	cat('\nFlexmix results\n');
	print(res)
	plot(res, main=st)
	dev.print(device=postscript, paste('CR_', st, '_Crit.eps', sep=''))
	# Restrict to the best model according to BIC
	resBIC = getModel(res, 'BIC')
	cat('\nBest Model\n')
	print(summary(resBIC))
	cat('\nModel parameters\n')
	print(round(parameters(resBIC),2))
	tab = matrix(0, dim(x)[2], attr(resBIC, 'k'))
	for (i in 1:dim(x)[2])
		tab[i,] = tapply(x[,i], attr(resBIC, 'cluster'), mean)
	rownames(tab) = colnames(x)
	colnames(tab) = paste('k=', 1:attr(resBIC, 'k'), sep='')
	print(round(tab, 2))
	cat('\nAttributes mean for each cluster\n')
	print(round(tab,2))
	# Fitting to get parameters confidence bounds
	resBICfit = refit(resBIC)
	cat('\nDescription of models\n')
	print(summary(resBICfit))
	print(plot(resBICfit, main=st))
	dev.copy2eps(file = paste('CR_', st, '_Coefficients.eps', sep=''))
	dev.off()
	# plotting observed vs predicted 
	# (in our case, always two clusters)
	postscript(paste('CR_', st, '_ObsPred.eps', sep=''))
	plot(predict(resBIC)$'Comp.1'[attr(resBIC,'cluster')==1] ~ 
		x$PM10[attr(resBIC,'cluster')==1],
		pch=1, xlim=range(x$PM10), ylim=range(predict(resBIC)),
		xlab='Observed', ylab='Predicted', main=st)
	points(predict(resBIC)$'Comp.2'[attr(resBIC,'cluster')==2] ~ 
		x$PM10[attr(resBIC,'cluster')==2], pch=3)
	abline(0,1,lty=2)
	y = c(predict(resBIC)$'Comp.1'[attr(resBIC,'cluster')==1], 
		predict(resBIC)$'Comp.2'[attr(resBIC,'cluster')==2])
	legend('topleft', legend=round(var(y) / var(x$PM10), 2), cex=2)
	legend('bottomright', pch=c(1,3), legend=c('k1','k2'))
	dev.off()
	sink()
	setwd('../..')
}

# Run method on the six stations
clus_reg(ail_comp, 'AIL')
clus_reg(gcm_comp, 'GCM')
clus_reg(gui_comp, 'GUI')
clus_reg(hri_comp, 'HRI')
clus_reg(jus_comp, 'JUS')
clus_reg(rep_comp, 'REP')










