# Loading data
# Be careful to change working directory
load('JolloisPoggiPortier.Rdata')


### using randomForest package
# load package
library(randomForest)
# Compute results
res <- randomForest(formula(jus_comp), data=jus_comp, importance=T)
# Print Performance 
print(res)
# Plot the marginal effect of the attribute 'NO'
partialPlot(res, jus_comp, 'NO', main='Marginal effect - NO')
# Variable importance: values and graph
importance(res)
varImpPlot(res, sort=T, main='RF - Variable importance')
# Marginal effects for all variables
par(mfrow=c(3,3))
partialPlot(res, jus_comp, 'NO', main='NO')
partialPlot(res, jus_comp, 'NO2', main='NO2')
partialPlot(res, jus_comp, 'SO2', main='SO2')
partialPlot(res, jus_comp, 'PL.som', main='PL.som')
partialPlot(res, jus_comp, 'T.moy', main='T.moy')
partialPlot(res, jus_comp, 'DV.dom', main='DV.dom')
partialPlot(res, jus_comp, 'VV.moy', main='VV.moy')
partialPlot(res, jus_comp, 'PA.moy', main='PA.moy')
partialPlot(res, jus_comp, 'GTrouen', main='GTrouen')


### using GAM package
# load package
library(mgcv)
# Compute the non-linear complete model
res <- gam(PM10 ~ s(NO) + s(NO2) + s(SO2) +
	s(T.min) + s(T.max) + s(T.moy) +
	s(DV.maxvv) + s(DV.dom) + s(VV.max) + s(VV.moy) +
	s(PL.som) + s(HR.min) + s(HR.max) + s(HR.moy) +
	s(PA.moy) + s(GTrouen) + s(GTlehavre), data=jus_comp)
# Print significavity tests for the variable
print(summary(res))
# Select significant variables
res1 <- gam(PM10 ~ s(NO) + s(NO2) + s(SO2) +
	s(T.max) +
	s(DV.maxvv) + s(VV.moy) +
	s(PL.som) + s(HR.max) + s(HR.moy) +
	s(PA.moy) + s(GTrouen), data=jus_comp)
# Print results
print(summary(res1))
# Plot non-linear variables effects
par(mfrow=c(3,4))
plot(res1)
# Linearisation of the effect of some variables (here 'NO2')
res2 <- gam(PM10 ~ s(NO) + NO2 + s(SO2) +
	s(T.max) +
	s(DV.maxvv) + s(VV.moy) +
	s(PL.som) + s(HR.max) + s(HR.moy) +
	s(PA.moy) + s(GTrouen), data=jus_comp)
# Print results
print(summary(res2))
# Plot of predicted vs obseved data + R-square value
plot(predict(res2) ~ PM10, data=jus_comp, xlab='Oberved', 
	ylab='Predicted', pch=3, main='JUS')
abline(0,1)
legend('topleft', 
	legend=paste('R-squared =',round(summary(res2)$r.sq, 2)))

### Flexmix
library(flexmix)
# centrage et reduction de la matrice de donnes
x = as.data.frame(scale(jus_comp))
# calcul des modles pour un nombre de classes entre 1 et 7
res = stepFlexmix(formula(x), data=x, k=1:7, nrep=10, 
	control=list(iter.max=500))
# Affichage des rsultats pour le choix du modle
print(res)
plot(res, main='JUS')
# Choix du "meilleur" modle selon le critre BIS
resBIC = getModel(res, 'BIC')
# Affichage des dtails de ce modle
print(summary(resBIC))
print(round(parameters(resBIC),2))
# Test de significativit des variables du modles
resBICfit = refit(resBIC)
# Affichage des rsultats de ces tests
print(summary(resBICfit))
# Graphique sur les coeeficients des variables
plot(resBICfit, main='JUS')


