load('JolloisPoggiPortier.Rdata')
library(mgcv)

### Specific function to deal with linear and non-linera formula
formule = function(x, lin, nonlin) {
	if (!is.null(lin))
		ch = paste(names(x)[1], '~', 
			paste(lin, collapse=' + '), '+', 
			paste(paste('s(',nonlin,')',sep=''), collapse=' + '), 
			collapse='')
	else
		ch = paste(names(x)[1], '~',  
			paste(paste('s(',nonlin,')',sep=''), collapse=' + '), 
			collapse='')
	return(formula(ch))
}

### automatic selection funtion
ModNL_GAM = function(x, st = 'XXX') {
	# shell is for Windows. 
	# Under Unix-like system, use system() function
	if (all(dir() != "GAM")) shell('mkdir GAM')
	setwd('GAM')
	if (all(dir() != st)) shell(paste('mkdir', st))
	setwd(st)
	# Select variables with p-value < 0.05
	m = gam(formule(x, NULL, names(x)[-1]), data=x)
	while (max(summary(m)$s.table[,4]) > 0.05) {
		x = x[,names(x)!=names(x)[which.max(summary(m)$s.table[,4])+1]]
		m = gam(formule(x, NULL, names(x)[-1]), data=x)
	}
	# Linearize effects for variables with edf < 1.1
	lin = names(x)[-1][summary(m)$edf < 1.1]
	nonlin = names(x)[-1][summary(m)$edf >= 1.1]
	m = gam(formule(x, lin, nonlin), data=x)
	# Print and plot results in specific files
	sink(paste('GAM_', st,'.txt',sep=''))
	print(summary(m))
	postscript(paste('GAM_', st,'_NLeffects.eps',sep=''))
	plot(m, scale=0, main=st, pages=1)
	dev.off()
	postscript(paste('GAM_', st,'_ObsPred.eps',sep=''))
	plot(predict(m) ~ PM10, data=x, xlab="PM10", 
		ylab="estimated PM10 estims", pch=3, 
		main=st)
	abline(0,1)
	legend('topleft', legend=round(summary(m)$r.sq, 2))
	dev.off()
	setwd("../..")
	sink()
}

# Run method on the six stations
ModNL_GAM(ail_comp, 'AIL')
ModNL_GAM(gcm_comp, 'GCM')
ModNL_GAM(gui_comp, 'GUI')
ModNL_GAM(hri_comp, 'HRI')
ModNL_GAM(jus_comp, 'JUS')
ModNL_GAM(rep_comp, 'REP')


